@@ -1,4 +1,4 @@
-;;; el-get-recipes.el --- Manage the external elisp bits and pieces you depend upon
+;;; el-get-recipes.el --- Manage the external elisp bits and pieces you depend upon -*- lexical-binding: t; -*-
 ;;
 ;; Copyright (C) 2010-2011 Dimitri Fontaine
 ;;
@@ -175,7 +175,7 @@ updated when the package itself is."
 
 
 ;;; "Fuzzy" data structure customization widgets
-(defun el-get-repeat-value-to-internal (widget element-or-list)
+(defun el-get-repeat-value-to-internal (_widget element-or-list)
   (el-get-as-list element-or-list))
 
 (defun el-get-repeat-match (widget value)
@@ -186,7 +186,7 @@ updated when the package itself is."
   :value-to-internal 'el-get-repeat-value-to-internal
   :match 'el-get-repeat-match)
 
-(defun el-get-symbol-match (widget value)
+(defun el-get-symbol-match (_widget value)
   (or (symbolp value) (stringp value)))
 
 (define-widget 'el-get-symbol 'symbol
@@ -220,15 +220,15 @@ being sent to the underlying shell."
 Each entry is a PLIST where the following properties are
 supported.
 
-If your property list is missing the :type property, then it's
+If your property list is missing the :type property, then it\\='s
 merged with the recipe one, so that you can override any
-definition provided by `el-get' recipes locally.
+definition provided by `el-get\\=' recipes locally.
 
 :name
 
     The name of the package. It can be different from the name of
     the directory where the package is stored (after a `git
-    clone' for example), in which case a symlink will be created.
+    clone\\=' for example), in which case a symlink will be created.
 
 :depends
 
@@ -238,49 +238,49 @@ definition provided by `el-get' recipes locally.
 
 :builtin
 
-    A string containing the Emacs version (see `emacs-version' variable)
+    A string containing the Emacs version (see `emacs-version\\=' variable)
     from which Emacs includes the recipe as a builtin.  For example,
-    `package.el' (the implementation of ELPA) is part of Emacs 24
+    `package.el\\=' (the implementation of ELPA) is part of Emacs 24
     but needs an external recipe for previous major versions.
 
 :type
 
     The type of the package, currently el-get offers support for
-    `apt-get', `elpa', `git', `github', `emacsmirror', `git-svn',
-    `bzr' `svn', `cvs', `darcs', `fink', `ftp', `emacswiki',
-    `http-tar', `pacman', `hg' and `http'. You can easily support
-    your own types here, see the variable `el-get-methods'.
+    `apt-get\\=', `elpa\\=', `git\\=', `github\\=', `emacsmirror\\=', `git-svn\\=',
+    `bzr\\=', `svn\\=', `cvs\\=', `darcs\\=', `fink\\=', `ftp\\=', `emacswiki\\=',
+    `http-tar\\=', `pacman\\=', `hg\\=' and `http\\='. You can easily support
+    your own types here, see the variable `el-get-methods\\='.
 
 :branch
 
-    Which branch to pull when using `git' (and by extension,
-    `github' and `emacsmirror', which are derived form `git') and
-    `hg' backends.  Also supported when installing el-get using
-    `el-get-install'.
+    Which branch to pull when using `git\\=' (and by extension,
+    `github\\=' and `emacsmirror\\=', which are derived form `git\\=') and
+    `hg\\=' backends.  Also supported when installing el-get using
+    `el-get-install\\='.
 
 :url
 
-    Where to fetch the package, only meaningful for `git' and
-    `http' types.
+    Where to fetch the package, only meaningful for `git\\=' and
+    `http\\=' types.
 
 :pkgname
 
     The name of the package for the underlying package management
-    system (`apt-get', `fink' or `pacman', also supported by
-    `github' and `emacsmirror'), which can be different from the
+    system (`apt-get\\=', `fink\\=' or `pacman\\=', also supported by
+    `github\\=' and `emacsmirror\\='), which can be different from the
     Emacs package name.
 
-    For the `github' type, this specifies the repo name to clone
+    For the `github\\=' type, this specifies the repo name to clone
     from Github. For example, for el-get, the package name would
-    be \"dimitri/el-get\". Note that the `emacsmirror' type is
-    just like the `github' type with the prefix \"emacsmirror/\"
+    be \"dimitri/el-get\". Note that the `emacsmirror\\=' type is
+    just like the `github\\=' type with the prefix \"emacsmirror/\"
     automatically supplied.
 
 :build
 
     Your build recipe, a list.
 
-    A build command C whose `car' is a symbol (see `symbolp') will be
+    A build command C whose `car\\=' is a symbol (see `symbolp\\=') will be
     replaced by (eval C).
 
     Then, each element of the recipe will be interpreted as
@@ -292,36 +292,36 @@ definition provided by `el-get' recipes locally.
       parsing is done.
 
     * Otherwise, if it is a list, any list sub-elements will be
-      recursively \"flattened\" (see `el-get-flatten').  The
+      recursively \"flattened\" (see `el-get-flatten\\=').  The
       resulting strings will be interpreted as individual shell
       arguments, appropriately quoted.
 
 :build/system-type
 
-    Your specific build recipe for a given `system-type' gets
+    Your specific build recipe for a given `system-type\\=' gets
     there and looks like :build.
 
 :load-path
 
-    A directory or a list of directories you want `el-get' to add
-    to your `load-path'. Those directories are relative to where
+    A directory or a list of directories you want `el-get\\=' to add
+    to your `load-path\\='. Those directories are relative to where
     the package gets installed.
 
 :compile
 
-    Allow to restrict what to byte-compile: by default, `el-get'
+    Allow to restrict what to byte-compile: by default, `el-get\\='
     will compile all elisp files in the :load-path directories,
     unless a :build command exists for the package source. Given
-    a :compile property, `el-get' will only byte-compile those
+    a :compile property, `el-get\\=' will only byte-compile those
     given files, directories or filename-regexpes in the property
-    value. This property can be a `listp' or a `stringp' if you
+    value. This property can be a `listp\\=' or a `stringp\\=' if you
     want to compile only one of those.
 
 :info
 
     This string allows you to setup a directory where to find a
-    'package.info' file, or a path/to/whatever.info file. It will
-    even run `ginstall-info' for you to create the `dir' entry so
+    \\='package.info\\=' file, or a path/to/whatever.info file. It will
+    even run `ginstall-info\\=' for you to create the `dir\\=' entry so
     that C-h i will be able to list the newly installed
     documentation. Note that you might need to kill (C-x k) your
     info buffer then C-h i again to be able to see the new menu
@@ -330,11 +330,11 @@ definition provided by `el-get' recipes locally.
 :load
 
     List of files to load, or a single file to load after having
-    installed the source but before `require'ing its features.
+    installed the source but before `require\\='ing its features.
 
 :features
 
-    List of features el-get will `require' for you.
+    List of features el-get will `require\\=' for you.
 
 :autoloads
 
@@ -347,10 +347,10 @@ definition provided by `el-get' recipes locally.
 :library
 
     When lazy, :library sets the file against which to register
-    the :after and :post-init forms for `eval-after-load'.  It
+    the :after and :post-init forms for `eval-after-load\\='.  It
     defaults to the first :feature, :pkgname (removing the
     \"username\" part for github and emacsmirror) or :package,
-    in that order.  See also `el-get-eval-after-load'.
+    in that order.  See also `el-get-eval-after-load\\='.
 
 :options
 
@@ -360,61 +360,61 @@ definition provided by `el-get' recipes locally.
     you want to use. Typically would be \"xzf\", but you might
     want to choose \"xjf\" for handling .tar.bz files e.g.
 
-    When using CVS, when it's set to \"login\", `el-get' will
-    first issue a `cvs login' against the server, asking you
+    When using CVS, when it\\='s set to \"login\", `el-get\\=' will
+    first issue a `cvs login\\=' against the server, asking you
     interactively (in the minibuffer) any password you might to
-    enter, and only then it will run the `cvs checkout' command.
+    enter, and only then it will run the `cvs checkout\\=' command.
 
 :module
 
-    Currently only used by the `cvs' support, allow you to
+    Currently only used by the `cvs\\=' support, allow you to
     configure the module you want to checkout in the given URL.
 
 :repo
 
-    Only used by the `elpa' support, a cons cell with the
-    form (NAME . URL), as in `package-archives'.  If the package
+    Only used by the `elpa\\=' support, a cons cell with the
+    form (NAME . URL), as in `package-archives\\='.  If the package
     source only specifies a URL, the URL will be used for NAME as
     well.
 
 :prepare
 
     This should be a lisp form to evaluate after both the
-    `Info-directory-list' and the `load-path' variables have been
+    `Info-directory-list\\=' and the `load-path\\=' variables have been
     taken care of, but before loading the package or any further
-    action from `el-get-init'.  It will be run with
-    `default-directory' set to the package directory.
+    action from `el-get-init\\='.  It will be run with
+    `default-directory\\=' set to the package directory.
 
 :before
 
-    This exactly like `:prepare' property, but is reserved for
-    user customizations in `el-get-sources'.  Recipe files should
-    not use this property.  It will be run just after `:prepare'.
+    This exactly like `:prepare\\=' property, but is reserved for
+    user customizations in `el-get-sources\\='.  Recipe files should
+    not use this property.  It will be run just after `:prepare\\='.
 
 :post-init
 
     Intended for use from recipes.  This should be a lisp form to
     evaluate once the :load and :features have been setup.  When
-    lazy, it will be registered for `eval-after-load' against the
-    recipe :library instead.  Like `:prepare', it will be run
-    with `default-directory' set to the package directory.
+    lazy, it will be registered for `eval-after-load\\=' against the
+    recipe :library instead.  Like `:prepare\\=', it will be run
+    with `default-directory\\=' set to the package directory.
 
 :after
 
-    This exactly like the `:post-init' property, but is reserved
-    for user customizations in `el-get-sources'.  Recipe files
+    This exactly like the `:post-init\\=' property, but is reserved
+    for user customizations in `el-get-sources\\='.  Recipe files
     should not use this property.  It will be run just after
-    `:post-init' and after any per-package user-init-file (see
-    `el-get-user-package-directory').
+    `:post-init\\=' and after any per-package user-init-file (see
+    `el-get-user-package-directory\\=').
 
 :lazy
 
-    Default to nil.  Allows to override `el-get-is-lazy' per
+    Default to nil.  Allows to override `el-get-is-lazy\\=' per
     package.
 
 :localname
 
-    Currently only used by both `http' and `ftp' supports, allows
+    Currently only used by both `http\\=' and `ftp\\=' supports, allows
     to specify the target name of the downloaded file.
 
     This option is useful if the package should be retrieved using
@@ -439,51 +439,51 @@ definition provided by `el-get' recipes locally.
     trusted (e.g. anyone is allowed to modify emacswiki anytime).
     For these cases you can set up a checksum value for a
     package, so you will notice if el-get tries to install a
-    version that you haven't seen before.  The installation will
+    version that you haven\\='t seen before.  The installation will
     simply fail and you will see the good and bad checksum values
-    in `*Messages*'.  To get the checksum value for a package
-    initially, install the package while `el-get-verbose' is on.
+    in `*Messages*\\='.  To get the checksum value for a package
+    initially, install the package while `el-get-verbose\\=' is on.
 
     Checksum calculation is currently supported by these methods
     with the following meaning:
 
-      * `http', `ftp' and `emacswiki' with the SHA1 of the downloaded file
-      * `git' and `hg' in which it is an alias for `:checkout' (see below)
+      * `http', `ftp\\=' and `emacswiki\\=' with the SHA1 of the downloaded file
+      * `git\\=' and `hg\\=' in which it is an alias for `:checkout\\=' (see below)
 
-    In the `git' and `hg' recipe types, note that while
-    `:checkout' will accept other things like branches, tags, and
-    so forth,`:checksum' must only be given a commit hash. This
+    In the `git\\=' and `hg\\=' recipe types, note that while
+    `:checkout\\=' will accept other things like branches, tags, and
+    so forth,`:checksum\\=' must only be given a commit hash. This
     will effectively lock the repository at a particular
-    revision. Note also that `:checksum' must be set to the full
+    revision. Note also that `:checksum\\=' must be set to the full
     hash, not just the first 6 or 8 characters (this restriction
     may be removed in the future).
 
 :checkout
 
-    For `git' or `hg' recipes, a branch name, tag, or other valid
-    argument to `git checkout'/`hg update'. If provided, this
-    overrides any value for the `:branch' property. Unlike the
-    `:branch' property, this can be any valid argument to
-    `checkout', including a tag name or a commit hash.
+    For `git\\=' or `hg\\=' recipes, a branch name, tag, or other valid
+    argument to `git checkout\\='/`hg update\\='. If provided, this
+    overrides any value for the `:branch\\=' property. Unlike the
+    `:branch\\=' property, this can be any valid argument to
+    `checkout\\=', including a tag name or a commit hash.
 
     When given a commit hash or tag, this will lock the repo at
     that specific revision. When given a branch name, this will
     always update the repo to the latest version of that branch,
     regardless of any changes made locally (in contrast to simply
-    using the `:branch' property, which will cause el-get-to try
+    using the `:branch\\=' property, which will cause el-get-to try
     to merge your local changes).
 
-    Currently this property only has meaning for `git' and `hg'
+    Currently this property only has meaning for `git\\=' and `hg\\='
     type recipes. Other VCS-based methods may implement support
     in the future.
 
 :shallow
 
     If set to t in a git recipe, git-clone will be run with
-    `--depth 1', which will create a so-called shallow clone by
+    `--depth 1\\=', which will create a so-called shallow clone by
     not downloading all the history of the repository. The
     default is controlled by the variable
-    `el-get-git-shallow-clone', which is nil by default.
+    `el-get-git-shallow-clone\\=', which is nil by default.
 
 :submodule
 
