@@ -1,4 +1,4 @@
-;;; el-get --- Manage the external elisp bits and pieces you depend upon
+;;; el-get --- Manage the external elisp bits and pieces you depend upon -*- lexical-binding: t; -*-
 ;;
 ;; Copyright (C) 2010-2011 Dimitri Fontaine
 ;;
@@ -55,6 +55,7 @@ fallback."
   "Notify the user using either the dbus based API or the `growl' one"
   (when (not (eq el-get-notify-type 'message))
     (unless (and (fboundp 'dbus-register-signal)
+                 (boundp 'dbus-compiled-version)
                  ;; avoid a bug in Emacs 24.0 under darwin
                  (ignore-errors (require 'notifications nil t)))
       ;; else try notify.el, there's a recipe for it
@@ -67,12 +68,13 @@ fallback."
          ;; Message only
          ((equal el-get-notify-type 'message) (error "Use `message' instead"))
          ;; Graphical notification
-         ((fboundp 'notifications-notify) (notifications-notify :title title
-                                                                :app-name "el-get"
-                                                                :app-icon (concat
-                                                                           (el-get-package-directory "el-get")
-                                                                           "/logo/el-get.png")
-                                                                :body message))
+         ((and (fboundp 'notifications-notify) (boundp 'dbus-compiled-version))
+          (notifications-notify :title title
+                                :app-name "el-get"
+                                :app-icon (concat
+                                           (el-get-package-directory "el-get")
+                                           "/logo/el-get.png")
+                                :body message))
          ((fboundp 'notify)               (notify title message))
          ((fboundp 'el-get-growl)         (el-get-growl title message))
          ;; Fallback
@@ -125,7 +127,7 @@ fallback."
   (el-get-verbose-message "el-get removed package %s" package))
 (add-hook 'el-get-post-remove-hooks 'el-get-post-remove-message)
 
-(defun el-get-post-error-message (package info)
+(defun el-get-post-error-message (package _info)
   "After PACKAGE fails to install, just message about it"
   (el-get-verbose-message "el-get failed to initialize package %s" package))
 (add-hook 'el-get-post-error-hooks 'el-get-post-error-message)
