@@ -1,12 +1,12 @@
-;;; el-get.el --- Manage the external elisp bits and pieces you depend upon
+;;; el-get.el --- Manage the external elisp bits and pieces you depend upon -*- lexical-binding: t; -*-
 ;;
 ;; Copyright (C) 2010-2012 Dimitri Fontaine
 ;;
 ;; Author: Dimitri Fontaine <dim@tapoueh.org>
 ;; URL: http://www.emacswiki.org/emacs/el-get
 ;; GIT: https://github.com/dimitri/el-get
-;; Package-Version: 20251110.758
-;; Package-Revision: 64112351b1f5
+;; Package-Version: 20260215.1117
+;; Package-Revision: 911c252afe76
 ;; Created: 2010-06-17
 ;; Keywords: emacs package elisp install elpa git git-svn bzr cvs svn darcs hg
 ;;           apt-get fink pacman http http-tar emacswiki
@@ -358,7 +358,7 @@ to wait until PACKAGE is loaded."
     (el-get-verbose-message "el-get-init: " init-deps)
     (cl-loop for p in init-deps do (el-get-do-init p) collect p)))
 
-(defun el-get-do-init (package &optional package-status-alist)
+(defun el-get-do-init (package &optional _package-status-alist)
   "Make the named PACKAGE available for use.
 
 Add PACKAGE's directory (or `:load-path' if specified) to the
@@ -394,7 +394,7 @@ prevent package.el from loading it."  package package)))
              (before   (plist-get source :before))
              (postinit (plist-get source :post-init))
              (after    (plist-get source :after))
-             (pkgname  (plist-get source :pkgname))
+             (_pkgname  (plist-get source :pkgname))
              (pdir     (el-get-package-directory package)))
 
         (el-get-error-unless-required-emacs-version source)
@@ -491,7 +491,7 @@ PACKAGE may be either a string or the corresponding symbol."
   ;; Start the chain of dependency installation
   (el-get-install-next-packages))
 
-(defun el-get-install-next-packages (&rest ignored)
+(defun el-get-install-next-packages (&rest _ignored)
   "Run as part of `el-get-post-init-hooks' when dealing with dependencies."
   (let ((package (pop el-get-next-packages)))
     (el-get-verbose-message "el-get-install-next-packages: %s" package)
@@ -583,13 +583,13 @@ PACKAGE may be either a string or the corresponding symbol."
       (funcall install package url 'el-get-post-install)
       (message "el-get install %s" package))))
 
-(defun el-get-reload (package &optional package-status-alist)
+(defun el-get-reload (package &optional _package-status-alist)
   "Reload PACKAGE."
+  (declare (advertised-calling-convention (package) "Feb 2015"))
   (interactive
    (progn
      (el-get-clear-status-cache)
      (list (el-get-read-package-with-status "Reload" "installed"))))
-  (declare (advertised-calling-convention (package) "Feb 2015"))
   (el-get-verbose-message "el-get-reload: %s" package)
   (el-get-with-status-sources ()
     (let* ((all-features features)
@@ -845,17 +845,17 @@ result of an actual problem."
 (defun el-get-cleanup (packages)
   "Clean up packages installed with el-get.
 
-In particular, keep all of the packages listed in the 'packages
+In particular, keep all of the packages listed in the \\='packages
 argument list, and also keep all of the packages that the listed
 packages depend on.  Get rid of everything else.  Note that
 el-get-cleanup will not remove el-get itself, regardless of
-whether or not el-get is listed in the 'packages argument list.
+whether or not el-get is listed in the \\='packages argument list.
 
 This is useful, for example, when we want to remove all packages not
 explicitly declared in the user-init-file (.emacs)."
   (let* ((packages-to-keep (el-get-dependencies
                             (mapcar 'el-get-as-symbol
-                                    (add-to-list 'packages 'el-get))))
+                                    (cons 'el-get packages))))
          (packages-to-remove (cl-set-difference
                               (mapcar 'el-get-as-symbol
                                       (el-get-list-package-names-with-status
@@ -952,8 +952,7 @@ considered \"required\"."
                                    unless (member p init-deps)
                                    collect p)
                         (mapcar 'el-get-as-symbol required)))
-         (install-deps (el-get-dependencies to-install))
-         done)
+         (install-deps (el-get-dependencies to-install)))
     (when req-inits       ; we can't init a pkg unless it's installed!
       (setq install-deps (append req-inits install-deps))
       (setq init-deps (cl-set-difference init-deps req-inits)))
@@ -961,38 +960,38 @@ considered \"required\"."
     (el-get-verbose-message "el-get-init-and-install: install %S" install-deps)
     (el-get-verbose-message "el-get-init-and-install: init %S" init-deps)
 
-    (cl-loop for p in install-deps
-             when (el-get-with-errors-as-warnings (format "while installing %s: " p)
-                    (el-get-do-install p))
-             collect p into done)
-    (cl-loop for p in init-deps
-             when (el-get-with-errors-as-warnings (format "while initializing %s: " p)
-                    (el-get-do-init p))
-             collect p into done)
-    done))
+    (append
+     (cl-loop for p in install-deps
+              when (el-get-with-errors-as-warnings (format "while installing %s: " p)
+                     (el-get-do-install p))
+              collect p)
+     (cl-loop for p in init-deps
+              when (el-get-with-errors-as-warnings (format "while initializing %s: " p)
+                     (el-get-do-init p))
+              collect p))))
 
 ;;;###autoload
 (defun el-get (&optional sync &rest packages)
   "Ensure that packages have been downloaded once and init them as needed.
 
-This will not update the sources by using `apt-get install' or
-`git pull', but it will ensure that:
+This will not update the sources by using `apt-get install\\=' or
+`git pull\\=', but it will ensure that:
 
 * the packages have been installed
 * load-path is set so their elisp files can be found
 * Info-directory-list is set so their info files can be found
 * Autoloads have been prepared and evaluated for each package
-* Any post-installation setup (e.g. `(require 'feature)') happens
+* Any post-installation setup (e.g. `(require \\='feature)\\=') happens
 
 When SYNC is nil (the default), all installations run
 concurrently, in the background.
 
-When SYNC is 'sync, each package will be installed synchronously,
+When SYNC is \\='sync, each package will be installed synchronously,
 and any error will stop it all.
 
-Please note that the `el-get-init' part of `el-get' is always
-done synchronously. There's `byte-compile' support though, and
-the packages you use are welcome to use `autoload' too.
+Please note that the `el-get-init\\=' part of `el-get\\=' is always
+done synchronously. There\\='s `byte-compile\\=' support though, and
+the packages you use are welcome to use `autoload\\=' too.
 
 PACKAGES is expected to be a list of packages you want to install
 or init.  When PACKAGES is omited (the default), the list of
